searchData={"items":[{"type":"module","title":"ExUnitParameterize","doc":"Parameterized tests for ExUnit.\n\nProvides the `parameterized_test` macro, implementing test parameterization for ExUnit.\n\nThe `parameterized_test` macro relies on the `ExUnit.Case.test` macro, and should support all the same use-cases.\nPlease file an issue if you find use-cases of test which parameterized_test doesn't handle.","ref":"ExUnitParameterize.html"},{"type":"module","title":"Examples: - ExUnitParameterize","doc":"defmodule ParameterizedTest do\n      use ExUnit.Case\n      import ExUnitParameterize\n\n      parameterized_test \"basic test\", [\n        [a: 1, b: 1, expected: 2],                # basic test[a:1, b:1, expected:2]\n        one_plus_two: [a: 1, b: 2, expected: 3],  # basic test[one_plus_two]\n        failing_case: [a: 1, b: 2, expected: 4]   # basic test[failing_case]\n      ] do\n        assert a + b == expected\n      end\n    end","ref":"ExUnitParameterize.html#module-examples"},{"type":"module","title":"Test naming - ExUnitParameterize","doc":"By default the string representation of the params will be appended to the test name, unless you\nprovide an explicit name.\n\nFor the example above the test names would be:\n  * basic test[a: 1, b: 1, expected: 2]\n  * basic test[one_plus_two]\n  * basic test[failing_case]\n\nIn case the name would be longer than the max atom size, the 1-based index will be used.","ref":"ExUnitParameterize.html#module-test-naming"},{"type":"macro","title":"ExUnitParameterize.parameterized_test/2","doc":"Defines a not implemented parametrized test.\n\nSee `ExUnit.Case.test/1`.","ref":"ExUnitParameterize.html#parameterized_test/2"},{"type":"macro","title":"Examples: - ExUnitParameterize.parameterized_test/2","doc":"defmodule NotImplementedCase do\n      use ExUnit.Case\n      import ExUnitParameterize\n      parameterized_test \"name\", [\n        [a: 1],\n        [a: 2],\n      ]\n    end","ref":"ExUnitParameterize.html#parameterized_test/2-examples"},{"type":"macro","title":"ExUnitParameterize.parameterized_test/4","doc":"Defines a parameterized test that uses the test context.\n\nSee `ExUnit.Case.test/3` and [ExUnit.Case#module-context](`m:ExUnit.Case#module-context`)","ref":"ExUnitParameterize.html#parameterized_test/4"},{"type":"macro","title":"Examples: - ExUnitParameterize.parameterized_test/4","doc":"defmodule ParameterizedCaseWithTagsAndContext do\n      use ExUnit.Case\n      import ExUnitParameterize\n\n      setup do\n        {:ok, spam: \"spam\"}\n      end\n\n      @tag foo_tag: \"foo\"\n      @tag :bar_tag\n      parameterized_test \"basic test with tags and context\", context, [\n        [a: 1, b: 2, expected: 3],\n        [a: 1, b: 2, expected: 4]\n      ] do\n        assert context[:foo_tag] == \"foo\"\n        assert context[:bar_tag] == true\n        assert context[:spam] == \"spam\"\n        assert a + b == expected\n      end\n\n    end","ref":"ExUnitParameterize.html#parameterized_test/4-examples"},{"type":"extras","title":"ExUnitParameterize","doc":"# ExUnitParameterize\n![tests](https://github.com/rciorba/yapara/actions/workflows/test.yaml/badge.svg?branch=master)\n\nParameterized tests for ExUnit.\n\nExamples:\n\n```elixir\ndefmodule ParameterizedTest do\n  use ExUnit.Case\n  import ExUnitParameterize\n\n  parameterized_test \"basic test\", [\n    [a: 1, b: 1, expected: 2],                # basic test[a:1, b:1, expected:2]\n    one_plus_two: [a: 1, b: 2, expected: 3],  # basic test[one_plus_two]\n    failing_case: [a: 1, b: 2, expected: 4]   # basic test[failing_case]\n  ] do\n    assert a + b == expected\n  end\nend\n\n```","ref":"readme.html"},{"type":"extras","title":"Test naming - ExUnitParameterize","doc":"By default the string representation of the params will be appended to the test name, unless you\nprovide an explicit name.\n\nFor the example above the test names would be:\n  * basic test[a: 1, b: 1, expected: 2]\n  * basic test[one_plus_two]\n  * basic test[failing_case]\n\nIn case the name would be longer than the max atom size, the 1-based index will be used.\n\n#","ref":"readme.html#test-naming"},{"type":"extras","title":"Note on spelling - ExUnitParameterize","doc":"Unfortunately, parameterize has many spellings, and there's no one single\n\"correct\" one. I've picked parameterize over parameterise, parametrize or parametrise, simply\nbecause it seems to be slightly more popular globally.","ref":"readme.html#note-on-spelling"},{"type":"extras","title":"Installation - ExUnitParameterize","doc":"ExUnitParameterize can be installed by adding `ex_unit_parameterize` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_unit_parameterize, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at [https://hexdocs.pm/ex_unit_parameterize](https://hexdocs.pm/ex_unit_parameterize).","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}